##  Viewing Synchronization Logs for Integration Runs
SaaS Discovery provides two types of synchronization logs:
  * Credentials check: Every 12 hours, the system checks the validity of the integration credentials and confirms the necessary permissions to request the needed data.
  * Application discovery: Every 12 hours, the system pulls data from the integrated systems.


You can view details on integration runs in the Sync Logging section of the administration area. By using synchronization logs, you can promptly identify any issues with the integration and view details on each failed integration run. For more information on synchronization logs, see [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD "Use synchronization logs to track the state of your integrations.").
![Synchronization Logs for SaaS Discovery Integrations in the Synchronization Logging Section](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750aba17a441014bc9b94a6d79cb5cd_LowRes.png)
Synchronization Logs for SaaS Discovery Integrations
